wait_for_shutdown_signal

Function wait_for_shutdown_signal 

pub async fn wait_for_shutdown_signal()
Waits for a shutdown signal.

On Unix, this waits for either SIGINT or SIGTERM, either of which are used to request a graceful shutdown: SIGINT interactively (Ctrl+C), and SIGTERM by process supervisors (systemd, container runtimes, Kubernetes) during rollouts, evictions, node drains, and container shutdown.

On Windows, this waits for either CTRL_C_EVENT (interactively) or CTRL_BREAK_EVENT, the latter being what a parent process supervisor sends via GenerateConsoleCtrlEvent to request a graceful stop.